==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/visualisers/AxisMethod.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file AxisMethod.h
    \brief Definition of the Template class AxisMethod.
    
    Magics Team - ECMWF 2005
    
    Started: Fri 7-Oct-2005
    
    Changes:
    
*/

#ifndef AxisMethod_H
#define AxisMethod_H

#include "magics.h"
#include "AxisMethodAttributes.h"
#include "Translator.h"
#include "Factory.h"
#include "AxisItem.h"
#include "Transformation.h"



namespace magics {

class Box;

class AxisMethod : public AxisMethodAttributes {

public:
	AxisMethod();
	virtual ~AxisMethod();
    
    virtual void set(const XmlNode& node) {
       AxisMethodAttributes::set(node);
    }
    virtual void set(const map<string, string>& map) {
    	AxisMethodAttributes::set(map);
    }
    virtual AxisMethod* clone() const {
        Log::dev() << "(const map<string, string&)---> to be checked!...\n";
        return new AxisMethod();
    }
    
    virtual void updateX(const Transformation&);
    virtual void updateY(const Transformation&);
    
    virtual double getMin() const { return AxisMethodAttributes::getMin(); }
    virtual double getMax() const { return AxisMethodAttributes::getMax(); }
    
    
    virtual void     prepare(double, double, AxisItems&) const;
    
    virtual void addItem(AxisItems& items, double val) const 
    	{ items.push_back(new AxisItem(val));  }
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
	 virtual double value(double val) const { return val; }

private:
    //! Copy constructor - No copy allowed
	AxisMethod(const AxisMethod&);
    //! Overloaded << operator to copy - No copy allowed
	AxisMethod& operator=(const AxisMethod&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const AxisMethod& p)
		{ p.print(s); return s; }

};

class LogarithmicAxisMethod : public AxisMethod
{
public:
	LogarithmicAxisMethod() {}
	virtual ~LogarithmicAxisMethod() {}
	void     prepare(double, double, AxisItems&) const;
	
	double value(double val) const { return exp10(val); }
	
	  virtual AxisMethod* clone() const {
        Log::dev() << "LogarithmicAxisMethod::clone()---> to be checked!...\n";
        return new LogarithmicAxisMethod();
    }
  
}; 


class LatitudeAxisMethod : public AxisMethod
{
public:
	LatitudeAxisMethod() {}
	virtual ~LatitudeAxisMethod() {}
	
	  virtual AxisMethod* clone() const {
        Log::dev() << "LatitudeAxisMethod::clone()---> to be checked!...\n";
        return new LatitudeAxisMethod();
    }
    void addItem(AxisItems& items, double val) const 
    	{ items.push_back(new AxisLatitudeItem(val));  }	
}; 

class LongitudeAxisMethod : public AxisMethod
{
public:
	LongitudeAxisMethod() {}
	virtual ~LongitudeAxisMethod() {}
	
	  virtual AxisMethod* clone() const {
        Log::dev() << "LatitudeAxisMethod::clone()---> to be checked!...\n";
        return new LongitudeAxisMethod();
    }
    void addItem(AxisItems& items, double val) const 
    	{ items.push_back(new AxisLongitudeItem(val));  }	
}; 

template <>
class Translator<string, AxisMethod> { 
public:
	AxisMethod* operator()(const string& val )
	{
		return SimpleObjectMaker<AxisMethod>::create(val);
	}     

	AxisMethod* magics(const string& param)
	{
		AxisMethod* object;
		ParameterManager::update(param, object);
		return object;
	}
};

} // namespace magics
#endif

==> magics++_2.18.15.orig.tar.gz: magics++-2.18.15/src/visualisers/AxisMethod.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file AxisMethod.h
    \brief Definition of the Template class AxisMethod.
    
    Magics Team - ECMWF 2005
    
    Started: Fri 7-Oct-2005
    
    Changes:
    
*/

#ifndef AxisMethod_H
#define AxisMethod_H

#include "magics.h"
#include "MagTranslator.h"
#include "Factory.h"
#include "AxisItem.h"
#include "Transformation.h"
#include "AxisMethodAttributes.h"


namespace magics {

class Box;
class Axis;

class AxisMethod: public AxisMethodAttributes {

public:
	AxisMethod();
	virtual ~AxisMethod();

	AxisMethod* clone() { assert(false); }
	virtual void set(const map<string, string>& map) {
		AxisMethodAttributes::set(map);
	}
	virtual void set(const XmlNode& node) {
			AxisMethodAttributes::set(node);
		}
    virtual void updateX(const Transformation&);
    virtual void updateY(const Transformation&);
    virtual void prepare(const Axis&, AxisItems&);


    double min() const { return min_; }
    double max() const { return max_; }

    virtual void addItem(AxisItems& items, double val) const 
    	{ items.push_back(new AxisItem(val));  }
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
	 virtual double value(double val) const { return val; }
	 double min_;
	 double max_;

private:
    //! Copy constructor - No copy allowed
	AxisMethod(const AxisMethod&);
    //! Overloaded << operator to copy - No copy allowed
	AxisMethod& operator=(const AxisMethod&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const AxisMethod& p)
		{ p.print(s); return s; }

};

class LogarithmicAxisMethod : public AxisMethod
{
public:
	LogarithmicAxisMethod() {}
	virtual ~LogarithmicAxisMethod() {}
	void     prepare(const Axis&, AxisItems&);
	
	double value(double val) const { return exp10(val); }
	

  
}; 
class HyperAxisMethod : public AxisMethod
{
public:
	HyperAxisMethod() {}
	virtual ~HyperAxisMethod() {}
	void     prepare(const Axis&, AxisItems&);
	
	
	

	 void updateX(const Transformation&);
	 void updateY(const Transformation&);
	 
protected:
	vector<double> hyperMin_;
	vector<double> hyperMax_;
	
		
}; 
class PositionListAxisMethod : public AxisMethod
{
public:
	PositionListAxisMethod() {}
	virtual ~PositionListAxisMethod() {}
	void     prepare(const Axis&, AxisItems&);
}; 



template <>
class MagTranslator<string, AxisMethod> { 
public:
	AxisMethod* operator()(const string& val )
	{
		return SimpleObjectMaker<AxisMethod>::create(val);
	}     

	AxisMethod* magics(const string& param)
	{
		AxisMethod* object;
		ParameterManager::update(param, object);
		return object;
	}

};

} // namespace magics
#endif
